package com.bionicbasket.app;

import java.text.DecimalFormat;

import com.bionicbasket.app.R;

import android.app.Activity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.TextView;

public class AdaptadorEstadisticas extends BaseAdapter {
	private final Activity actividad;
	final int PUNTOS = 1;
	final int MEDIA_PUNTOS = 2;
	final int FALTAS = 3;
	final int MEDIA_FALTAS = 4;
	final int JUGADOS = 5;

	public AdaptadorEstadisticas(Activity actividad) {
		super();

		int i, j;

		// Para presentar el dato buscado de forma ordenada, se aplica el método
		// de la burbuja en cada uno de los casos que el usuario pide mostrar
		for (i = 0; i < AlmacenDatos.datos.size() - 1; i++) {
			for (j = 0; j < AlmacenDatos.datos.size() - i - 1; j++) {
				// La variable global dato_estadistico indica la estadística
				// concreta que el usuario ha pedido que se le muestre
				switch (MainActivity.dato_estadistico) {
				case PUNTOS:
					if (AlmacenDatos.datos.get(j + 1).getPuntos() > AlmacenDatos.datos
							.get(j).getPuntos()) {
						burbuja(j);
					}
					break;

				case MEDIA_PUNTOS:
					if (AlmacenDatos.datos.get(j + 1).getMedia_puntos() > AlmacenDatos.datos
							.get(j).getMedia_puntos()) {
						burbuja(j);
					}
					break;

				case FALTAS:
					if (AlmacenDatos.datos.get(j + 1).getFaltas() > AlmacenDatos.datos
							.get(j).getFaltas()) {
						burbuja(j);
					}
					break;

				case MEDIA_FALTAS:
					if (AlmacenDatos.datos.get(j + 1).getMedia_faltas() > AlmacenDatos.datos
							.get(j).getMedia_faltas()) {
						burbuja(j);
					}
					break;

				case JUGADOS:
					if (AlmacenDatos.datos.get(j + 1).getJugados() > AlmacenDatos.datos
							.get(j).getJugados()) {
						burbuja(j);
					}
					break;

				default:
					break;
				}
			}
		}

		this.actividad = actividad;
	}

	public View getView(int position, View convertView, ViewGroup parent) {
		LayoutInflater inflater = actividad.getLayoutInflater();
		View view = inflater.inflate(R.layout.elemento_estadistica, null, true);

		// Nombre del jugador
		TextView nombre = (TextView) view.findViewById(R.id.nombre);
		nombre.setText(AlmacenDatos.datos.elementAt(position).getNombre());

		// Dato estadístico (se define un número decimal para presentarlo con
		// dos números decimales como máximo)
		TextView dato = (TextView) view.findViewById(R.id.dato);
		DecimalFormat resultado_decimal = new DecimalFormat("#.##");
		// La variable global dato_estadistico indica la estadística concreta
		// que el usuario ha pedido que se le muestre
		switch (MainActivity.dato_estadistico) {
		case PUNTOS:
			dato.setText(Integer.toString(AlmacenDatos.datos
					.elementAt(position).getPuntos()));
			break;

		case MEDIA_PUNTOS:
			if (AlmacenDatos.datos.elementAt(position).getMedia_puntos() > 0.0) {
				// Si ha jugado partidos se muestra la media de forma formateada
				String dato_formateado = resultado_decimal
						.format(AlmacenDatos.datos.elementAt(position)
								.getMedia_puntos());
				dato.setText(dato_formateado);
			} else {
				// Si no ha jugado partidos, se muestra un guión
				dato.setText("-");
			}
			break;

		case FALTAS:
			dato.setText(Integer.toString(AlmacenDatos.datos
					.elementAt(position).getFaltas()));
			break;

		case MEDIA_FALTAS:
			if (AlmacenDatos.datos.elementAt(position).getMedia_faltas() > 0.0) {
				// Si ha jugado partidos se muestra la media de forma formateada
				String dato_formateado = resultado_decimal
						.format(AlmacenDatos.datos.elementAt(position)
								.getMedia_faltas());
				dato.setText(dato_formateado);
			} else {
				// Si no ha jugado partidos, se muestra un guión
				dato.setText("-");
			}
			break;

		case JUGADOS:
			dato.setText(Integer.toString(AlmacenDatos.datos
					.elementAt(position).getJugados()));
			break;

		default:
			break;
		}

		return view;
	}

	public int getCount() {
		return AlmacenDatos.datos.size();
	}

	public Object getItem(int arg0) {
		return AlmacenDatos.datos.elementAt(arg0);
	}

	public long getItemId(int position) {
		return position;
	}

	// Método de ordenación de la burbuja aplicado a la variable datos
	public void burbuja(int j) {
		Jugador aux;

		aux = AlmacenDatos.datos.get(j + 1);
		AlmacenDatos.datos.set(j + 1, AlmacenDatos.datos.get(j));
		AlmacenDatos.datos.set(j, aux);
	}
}