package com.bionicbasket.app;

import java.util.Vector;

import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.text.Html;

public class AlmacenDatosSQLite extends SQLiteOpenHelper implements
		AlmacenDatos {

	// Constructor
	public AlmacenDatosSQLite(Context context) {
		super(context, "bionic", null, 1);
	}

	@Override
	public void onCreate(SQLiteDatabase db) {
		// Crea la base de datos de estadísticas de cada jugador
		db.execSQL("CREATE TABLE estadisticas (_id INTEGER PRIMARY KEY AUTOINCREMENT, "
				+ "nombre TEXT, puntos INTEGER, faltas INTEGER, "
				+ "tecnicas INTEGER, jugados INTEGER)");

		// Crea la base de datos del calendario de partidos
		db.execSQL("CREATE TABLE calendario (_id INTEGER PRIMARY KEY AUTOINCREMENT, "
				+ "fecha TEXT, hora TEXT, jornada INTEGER, pabellon TEXT, "
				+ "local TEXT, visitante TEXT, resultado TEXT)");

		// Crea la base de datos de la clasificación de los equipos
		db.execSQL("CREATE TABLE clasificacion (_id INTEGER PRIMARY KEY AUTOINCREMENT, "
				+ "posicion INTEGER, nombre TEXT, puntos INTEGER, jugados INTEGER, "
				+ "ganados INTEGER, perdidos INTEGER, a_favor INTEGER, en_contra INTEGER)");
	}

	@Override
	public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
		// Para nuevas versiones de la base de datos
	}

	// Guarda las estadísticas de los jugadores en base a los datos descargados
	// de Internet
	public void guardarEstadisticas(String[] lineas) {
		int i = 1;
		String nombre = "";
		String nombre_separado[];
		int puntos = 0, faltas = 0, tecnicas = 0, jugados = 0;
		Vector<String> nombres = new Vector<String>();
		final int NOMBRE = 0;
		final int PUNTOS = 1;
		final int FALTAS = 2;
		final int TECNICAS = 3;
		final int JUGADOS = 4;

		SQLiteDatabase db = getWritableDatabase();

		// Para comprobar si hay nombres ya guardados, se realiza una búsqueda
		// en la base de datos de todos los nombres y se guardan en un vector
		// para su utilización
		Cursor cursor = db.rawQuery("SELECT nombre FROM estadisticas", null);

		while (cursor.moveToNext()) {
			nombres.add(cursor.getString(0));
		}

		cursor.close();

		// Se lee la información descargada hasta llegar a la marca de
		// finalización del listado de jugadores
		while (!lineas[i].equals("Fin del listado de jugadores")) {
			// Se extraen los datos a guardar, que vienen indicados cada uno en
			// una línea correspondiente a las constantes declaradas
			nombre = lineas[i + NOMBRE];
			// El nombre viene como apellido, nombre y se procede a modificarlo
			nombre_separado = nombre.split(", ");
			nombre = nombre_separado[1] + " " + nombre_separado[0];
			puntos = Integer.parseInt(lineas[i + PUNTOS]);
			faltas = Integer.parseInt(lineas[i + FALTAS]);
			tecnicas = Integer.parseInt(lineas[i + TECNICAS]);
			jugados = Integer.parseInt(lineas[i + JUGADOS]);

			// Se define una variable booleana para comprobar si el nombre leído
			// corresponde con alguno de los nombres ya existentes en la base de
			// datos para actualizar o insertar en caso de que no exista
			int j = 0;
			boolean encontrado = false;
			while (!encontrado && !nombres.isEmpty() && j < nombres.size()) {
				if (nombres.get(j).equals(nombre)) {
					encontrado = true;
				}
				j++;
			}

			if (encontrado) {
				// Se actualizan las estadísticas del jugador en caso de haber
				// encontrado ya un registro para el mismo
				db.execSQL("UPDATE estadisticas SET puntos = " + puntos
						+ ", faltas = " + faltas + ", tecnicas = " + tecnicas
						+ ", jugados = " + jugados + " WHERE nombre = '"
						+ nombre + "'");
			} else {
				// Se insertan las estadísticas de un nuevo jugador en caso de
				// no existir ningún registro del mismo
				db.execSQL("INSERT INTO estadisticas VALUES (null, '" + nombre
						+ "', " + puntos + ", " + faltas + ", " + tecnicas
						+ ", " + jugados + ")");
			}

			i += 5;
		}

		db.close();
	}

	// Carga las estadísticas guardadas en la base de datos en una clase para un
	// mejor manejo durante la ejecución
	public void cargarEstadisticas() {
		SQLiteDatabase db = getReadableDatabase();
		final int NOMBRE = 0;
		final int PUNTOS = 1;
		final int FALTAS = 2;
		final int JUGADOS = 3;

		// Se obtienen los datos requeridos desde la base de datos
		Cursor cursor = db.rawQuery("SELECT nombre, puntos, faltas, "
				+ "jugados FROM estadisticas", null);

		// El vector datos del almacén de datos se vacía para reincorporar los
		// nuevos datos y evitar así tener que hacer una búsqueda de si un
		// jugador ya tiene datos guardados
		datos.clear();

		// Se recorren los datos y se guardan en el vector datos
		while (cursor.moveToNext()) {
			Jugador d = new Jugador();

			d.nombre = cursor.getString(NOMBRE);
			d.puntos = cursor.getInt(PUNTOS);
			d.faltas = cursor.getInt(FALTAS);
			d.jugados = cursor.getInt(JUGADOS);
			// Cálculo de la media estadística en base a los partidos jugados
			if (d.jugados > 0) {
				d.media_puntos = (d.puntos * 1.0) / d.jugados;
				d.media_faltas = (d.faltas * 1.0) / d.jugados;
			}

			datos.add(d);
		}

		cursor.close();
		db.close();
	}

	// Guarda el calendario del equipo en base a los datos descargados de
	// Internet
	public void guardarCalendario(String[] lineas) {
		int i = 1;
		String fecha = "", hora = "", pabellon = "", local = "", visitante = "", resultado = "";
		int jornada = 0;
		Vector<Integer> jornadas = new Vector<Integer>();
		final int FECHA = 0;
		final int HORA = 1;
		final int JORNADA = 2;
		final int PABELLON = 3;
		final int LOCAL = 4;
		final int VISITANTE = 5;
		final int RESULTADO = 6;

		SQLiteDatabase db = getWritableDatabase();

		// Para comprobar si hay jornadas ya guardadas, se realiza una búsqueda
		// en la base de datos de todas las jornadas y se guardan en un vector
		// para su utilización
		Cursor cursor = db.rawQuery("SELECT jornada FROM calendario", null);

		while (cursor.moveToNext()) {
			jornadas.add(cursor.getInt(0));
		}

		cursor.close();

		// Se debe llegar al inicio del calendario, el cual está colocado justo
		// al final del listado de jugadores, por lo que se recorren los datos
		// hasta llegar a él
		while (!lineas[i].equals("Fin del listado de jugadores")) {
			i++;
		}
		i++;

		// Se lee la información descargada hasta llegar a la marca de
		// finalización del calendario
		while (!lineas[i].equals("Fin del calendario")) {
			// Se extraen los datos a guardar, que vienen indicados cada uno en
			// una línea correspondiente a las constantes declaradas
			fecha = lineas[i + FECHA];
			hora = lineas[i + HORA];
			jornada = Integer.parseInt(lineas[i + JORNADA]);
			pabellon = lineas[i + PABELLON];
			local = lineas[i + LOCAL];
			visitante = lineas[i + VISITANTE];
			resultado = lineas[i + RESULTADO];

			// Reemplazo de los carácteres especiales de HTML
			fecha = Html.fromHtml(fecha).toString();
			pabellon = Html.fromHtml(pabellon).toString();

			// Se define una variable booleana para comprobar si la jornada
			// leída corresponde con alguna de las jornadas ya existentes en la
			// base de datos para actualizar o insertar en caso de que no exista
			int j = 0;
			boolean encontrado = false;
			while (!encontrado && !jornadas.isEmpty() && j < jornadas.size()) {
				if (jornadas.get(j).equals(jornada)) {
					encontrado = true;
				}
				j++;
			}

			if (encontrado) {
				// Se actualiza la jornada en caso de haber encontrado ya un
				// registro para la misma
				db.execSQL("UPDATE calendario SET fecha ='" + fecha
						+ "', hora = '" + hora + "', pabellon = '" + pabellon
						+ "', local = '" + local + "', visitante = '"
						+ visitante + "', resultado = '" + resultado + "' "
						+ "WHERE jornada = " + jornada);
			} else {
				// Se inserta una nueva jornada en caso de no existir ningún
				// registro de la misma
				db.execSQL("INSERT INTO calendario VALUES (null, '" + fecha
						+ "', '" + hora + "', " + jornada + ", '" + pabellon
						+ "', '" + local + "', '" + visitante + "', '"
						+ resultado + "')");
			}

			i += 7;
		}

		db.close();
	}

	// Carga el calendario guardado en la base de datos en una clase para un
	// mejor manejo durante la ejecución
	public void cargarCalendario() {
		SQLiteDatabase db = getReadableDatabase();
		final int FECHA = 0;
		final int HORA = 1;
		final int JORNADA = 2;
		final int PABELLON = 3;
		final int LOCAL = 4;
		final int VISITANTE = 5;
		final int RESULTADO = 6;

		// Se obtienen los datos requeridos desde la base de datos
		Cursor cursor = db.rawQuery(
				"SELECT fecha, hora, jornada, pabellon, local, "
						+ "visitante, resultado FROM calendario", null);

		// El vector jornadas del almacén de datos se vacía para reincorporar
		// las nuevas jornadas y evitar así tener que hacer una búsqueda de si
		// una jornada ya tiene datos guardados
		jornadas.clear();

		// Se recorren las jornadas y se guardan en el vector jornadas
		while (cursor.moveToNext()) {
			Jornada j = new Jornada();

			j.fecha = cursor.getString(FECHA);
			j.hora = cursor.getString(HORA);
			j.jornada = cursor.getInt(JORNADA);
			j.pabellon = cursor.getString(PABELLON);
			j.local = cursor.getString(LOCAL);
			j.visitante = cursor.getString(VISITANTE);
			j.resultado = cursor.getString(RESULTADO);

			jornadas.add(j);
		}

		cursor.close();
		db.close();
	}

	// Guarda la clasificación de los equipos en base a los datos descargados de
	// Internet
	public void guardarClasificacion(String[] lineas) {
		int i = 1;
		String nombre = "";
		int posicion = 0, puntos = 0, jugados = 0, ganados = 0, perdidos = 0, a_favor = 0, en_contra = 0;
		Vector<Integer> posiciones = new Vector<Integer>();
		final int POSICION = 0;
		final int NOMBRE = 1;
		final int PUNTOS = 2;
		final int JUGADOS = 3;
		final int GANADOS = 4;
		final int PERDIDOS = 5;
		final int A_FAVOR = 6;
		final int EN_CONTRA = 7;

		SQLiteDatabase db = getWritableDatabase();

		// Para comprobar si hay posiciones ya guardadas, se realiza una
		// búsqueda en la base de datos de todas las posiciones y se guardan en
		// un vector para su utilización
		Cursor cursor = db.rawQuery("SELECT posicion FROM clasificacion", null);

		while (cursor.moveToNext()) {
			posiciones.add(cursor.getInt(0));
		}

		cursor.close();

		// Se debe llegar al inicio de la clasificación, la cual está colocada
		// justo al final del calendario, por lo que se recorren los datos hasta
		// llegar a ella
		while (!lineas[i].equals("Fin del calendario")) {
			i++;
		}
		i++;

		// Se lee la información descargada hasta llegar a la marca de
		// finalización de la clasificación
		while (!lineas[i].equals("Fin de la clasificación")) {
			// Se extraen los datos a guardar, que vienen indicados cada uno en
			// una línea correspondiente a las constantes declaradas
			posicion = Integer.parseInt(lineas[i + POSICION]);
			nombre = lineas[i + NOMBRE];
			puntos = Integer.parseInt(lineas[i + PUNTOS]);
			jugados = Integer.parseInt(lineas[i + JUGADOS]);
			ganados = Integer.parseInt(lineas[i + GANADOS]);
			perdidos = Integer.parseInt(lineas[i + PERDIDOS]);
			a_favor = Integer.parseInt(lineas[i + A_FAVOR]);
			en_contra = Integer.parseInt(lineas[i + EN_CONTRA]);

			// Se define una variable booleana para comprobar si la posición
			// leída corresponde con alguna de las posiciones ya existentes en
			// la base de datos para actualizar o insertar en caso de que no
			// exista
			int j = 0;
			boolean encontrado = false;
			while (!encontrado && !posiciones.isEmpty()
					&& j < posiciones.size()) {
				if (posiciones.get(j).equals(posicion)) {
					encontrado = true;
				}
				j++;
			}

			if (encontrado) {
				// Se actualiza la posición en caso de haber encontrado ya un
				// registro para la misma
				db.execSQL("UPDATE clasificacion SET nombre = '" + nombre
						+ "', puntos = " + puntos + ", jugados = " + jugados
						+ ", ganados = " + ganados + ", perdidos = " + perdidos
						+ ", a_favor = " + a_favor + ", en_contra = "
						+ en_contra + " WHERE posicion = " + posicion);
			} else {
				// Se inserta una nueva posición en caso de no existir ningún
				// registro de la misma
				db.execSQL("INSERT INTO clasificacion VALUES (null, "
						+ posicion + ", '" + nombre + "', " + puntos + ", "
						+ jugados + ", " + ganados + ", " + perdidos + ", "
						+ a_favor + ", " + en_contra + ")");
			}

			i += 8;
		}

		db.close();
	}

	// Carga la clasificación guardada en la base de datos en una clase para un
	// mejor manejo durante la ejecución
	public void cargarClasificacion() {
		SQLiteDatabase db = getReadableDatabase();
		final int POSICION = 0;
		final int NOMBRE = 1;
		final int PUNTOS = 2;
		final int JUGADOS = 3;
		final int GANADOS = 4;
		final int PERDIDOS = 5;
		final int A_FAVOR = 6;
		final int EN_CONTRA = 7;

		// Se obtienen los datos requeridos desde la base de datos
		Cursor cursor = db.rawQuery(
				"SELECT posicion, nombre, puntos, jugados, ganados, perdidos, "
						+ "a_favor, en_contra FROM clasificacion", null);

		// El vector posiciones del almacén de datos se vacía para reincorporar
		// las nuevas posiciones y evitar así tener que hacer una búsqueda de si
		// una posición ya tiene datos guardados
		posiciones.clear();

		// Se recorren las jornadas y se guardan en el vector jornadas
		while (cursor.moveToNext()) {
			Posicion p = new Posicion();

			p.posicion = cursor.getInt(POSICION);
			p.nombre = cursor.getString(NOMBRE);
			p.puntos = cursor.getInt(PUNTOS);
			p.jugados = cursor.getInt(JUGADOS);
			p.ganados = cursor.getInt(GANADOS);
			p.perdidos = cursor.getInt(PERDIDOS);
			p.a_favor = cursor.getInt(A_FAVOR);
			p.en_contra = cursor.getInt(EN_CONTRA);

			posiciones.add(p);
		}

		cursor.close();
		db.close();
	}

}
