package com.bionicbasket.app;

import java.util.Calendar;
import java.util.GregorianCalendar;

import android.app.IntentService;
import android.app.Notification;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.content.Intent;

public class ComprobarProximoPartido extends IntentService {
	// NOTIFICACIÓN //
	private NotificationManager nm;
	private static final int ID_NOTIFICACION_CREAR = 1;

	// ALMACÉN DE DATOS //
	public AlmacenDatos almacen = new AlmacenDatosSQLite(this);

	// Constructor
	public ComprobarProximoPartido() {
		super("ComprobarProximoPartido");
	}

	@Override
	synchronized protected void onHandleIntent(Intent intent) {
		Calendar fecha_actual = GregorianCalendar.getInstance();
		Calendar fecha_partido = new GregorianCalendar();
		int i;
		boolean fecha_superada = false;

		// Guardado de los datos en la clase correspondiente
		almacen.cargarEstadisticas();
		almacen.cargarCalendario();
		almacen.cargarClasificacion();

		nm = (NotificationManager) getSystemService(NOTIFICATION_SERVICE);

		// Se va a comprobar si el día siguiente al actual existe un partido
		// guardado y, si existe, lanzará una notificación de aviso
		i = 0;
		while (i < AlmacenDatos.jornadas.size() && !fecha_superada) {
			// Se extrae, desde el String fecha del vector jornadas, la fecha
			// exacta del partido para su manejo
			String f = AlmacenDatos.jornadas.get(i).getFecha();
			String fecha_part[] = f.split(", ");
			String dia_mes_anyo[] = fecha_part[1].split("/");
			int dia_partido = Integer.parseInt(dia_mes_anyo[0]);
			// El mes se representa de 0 a 11 en la clase Calendar
			int mes_partido = Integer.parseInt(dia_mes_anyo[1]) - 1;
			int anyo_partido = Integer.parseInt(dia_mes_anyo[2]);

			// Construcción de la fecha del partido en un objeto de la clase
			// Calendar
			fecha_partido.set(anyo_partido, mes_partido, dia_partido);

			// Se comprueba si la fecha del partido es al día siguiente
			if (fecha_partido.get(Calendar.DAY_OF_YEAR)
					- fecha_actual.get(Calendar.DAY_OF_YEAR) == 1) {

				// Se extrae la hora y el pabellón de la jornada para notificar
				String hora = AlmacenDatos.jornadas.get(i).getHora();
				String pabellon = AlmacenDatos.jornadas.get(i).getPabellon();

				// Construcción de la notificación
				Notification notificacion = new Notification(
						R.drawable.ic_launcher, "¡Mañana hay partido Biònic!",
						System.currentTimeMillis());

				// Se envía el índice del vector jornadas en donde se encuentra
				// el partido que queremos notificar
				Intent intencion = new Intent(this, NotificacionPartido.class);
				intencion.putExtra("indice", i);

				PendingIntent intencionPendiente = PendingIntent.getActivity(
						getApplicationContext(), 0, intencion,
						Intent.FLAG_ACTIVITY_NEW_TASK);

				// En la notificación aparecerá la hora y el pabellón del
				// partido
				notificacion
						.setLatestEventInfo(this, "Biònic Bàsquet", "A las "
								+ hora + " en " + pabellon, intencionPendiente);

				notificacion.defaults |= Notification.DEFAULT_ALL;
				notificacion.flags |= Notification.FLAG_AUTO_CANCEL;

				nm.notify(ID_NOTIFICACION_CREAR, notificacion);
			}

			// En el caso de que la fecha del partido leído sea posterior a la
			// fecha actual, lo indicaremos para no continuar con la búsqueda
			if (fecha_partido.after(fecha_actual)) {
				fecha_superada = true;
			}

			i++;
		}
	}
}
