package com.bionicbasket.app;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;

import android.app.Activity;
import android.app.AlarmManager;
import android.app.PendingIntent;
import android.app.ProgressDialog;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.content.SharedPreferences.Editor;
import android.os.AsyncTask;
import android.os.Bundle;
import android.os.StrictMode;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;
import android.widget.Button;
import android.widget.ImageView;

public class MainActivity extends Activity {
	// BOTONES //
	Button calendario;
	Button clasificacion;
	Button estadisticas;
	Button contacto;

	// Indica el tipo de dato solicitado
	public static int dato_estadistico;

	// ALMACÉN DE DATOS //
	public AlmacenDatos almacen = new AlmacenDatosSQLite(this);

	// Indica si los datos ya han sido cargados
	public Boolean datos_cargados = false;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);

		StrictMode.setThreadPolicy(new StrictMode.ThreadPolicy.Builder()
				.permitNetwork().build());

		// Escuchadores de eventos para los botones
		calendario = (Button) findViewById(R.id.btn_calendario);
		calendario.setOnClickListener(new OnClickListener() {

			@Override
			public void onClick(View v) {
				lanzarCalendario(null);
			}
		});

		clasificacion = (Button) findViewById(R.id.btn_clasificacion);
		clasificacion.setOnClickListener(new OnClickListener() {

			@Override
			public void onClick(View v) {
				lanzarClasificacion(null);
			}
		});

		estadisticas = (Button) findViewById(R.id.btn_estadisticas);
		estadisticas.setOnClickListener(new OnClickListener() {

			@Override
			public void onClick(View v) {
				lanzarEstadisticas(null);
			}
		});

		contacto = (Button) findViewById(R.id.btn_contacto);
		contacto.setOnClickListener(new OnClickListener() {

			@Override
			public void onClick(View v) {
				lanzarContacto(null);

			}
		});

		// Se comprueba, mediante preferencias, si es la primera vez que se
		// ejecuta la aplicación
		SharedPreferences preferencias = getSharedPreferences("primeraVez",
				Context.MODE_PRIVATE);
		boolean primeraVez = preferencias.getBoolean("primeraVez", true);

		if (primeraVez) {
			// En el caso de ser la primera vez que se ejecuta la aplicación,
			// se guarda en las preferencias este hecho para no volver a
			// repetirlo
			Editor editor = preferencias.edit();
			editor.putBoolean("primeraVez", false);
			editor.commit();

			// Se crea una alarma que ejecutará un servicio cada día para
			// comprobar si hay partido al día siguiente y lanzar una
			// notificación al respecto
			Intent i = new Intent(this, ComprobarProximoPartido.class);
			PendingIntent intencionPendiente = PendingIntent.getService(this,
					0, i, PendingIntent.FLAG_UPDATE_CURRENT);
			AlarmManager alarma = (AlarmManager) getSystemService(ALARM_SERVICE);
			alarma.setRepeating(AlarmManager.RTC_WAKEUP,
					System.currentTimeMillis() + (30 * 1000),
					AlarmManager.INTERVAL_DAY, intencionPendiente);
		}
	}

	@Override
	protected void onResume() {
		super.onResume();

		// Descarga de datos programada cada vez que se abra la aplicación
		if (!datos_cargados) {
			new DescargarDatos().execute();
			datos_cargados = true;
		}

		// Construcción y visualización de la animación
		ImageView imagen = (ImageView) findViewById(R.id.logo);
		Animation animacion = AnimationUtils.loadAnimation(this,
				R.anim.animacion);
		imagen.startAnimation(animacion);
	}

	// Guarda el estado para no volver a cargar los datos en la rotación del
	// dispositivo
	@Override
	protected void onSaveInstanceState(Bundle estadoGuardado) {
		super.onSaveInstanceState(estadoGuardado);
		estadoGuardado.putBoolean("datos_cargados", datos_cargados);
	}

	// Carga el estado guardado
	@Override
	protected void onRestoreInstanceState(Bundle estadoGuardado) {
		super.onRestoreInstanceState(estadoGuardado);
		datos_cargados = estadoGuardado.getBoolean("datos_cargados");
	}

	// Lanza la actividad que muestra el calendario
	public void lanzarCalendario(View v) {
		Intent i = new Intent(this, Calendario.class);
		startActivity(i);
	}

	// Lanza la actividad que muestra la clasificación
	public void lanzarClasificacion(View v) {
		Intent i = new Intent(this, Clasificacion.class);
		startActivity(i);
	}

	// Lanza la actividad que muestra las estadísticas
	public void lanzarEstadisticas(View v) {
		Intent i = new Intent(this, Estadisticas.class);
		startActivity(i);
	}

	// Lanza la actividad que muestra los datos de contacto
	public void lanzarContacto(View v) {
		Intent i = new Intent(this, AcercaDe.class);
		startActivity(i);
	}

	// Realiza una búsqueda en una web predeterminada con la totalidad de datos
	// que la aplicación va a necesitar devolviendo un array de Strings con la
	// totalidad de las líneas leídas
	String[] busquedaDatos() throws Exception {
		String[] lineas = {};

		// Dirección en la que están depositados los datos
		URL url = new URL("http://jcolas.esy.es/puntuaciones/equipo_bionic.php");
		HttpURLConnection conexion = (HttpURLConnection) url.openConnection();
		conexion.setRequestProperty("User-Agent",
				"Mozilla/5.0 (Windows NT 6.1)");
		if (conexion.getResponseCode() == HttpURLConnection.HTTP_OK) {
			BufferedReader reader = new BufferedReader(new InputStreamReader(
					conexion.getInputStream()));
			// La web muestra una estructura de datos que contiene únicamente
			// texto, por tanto al realizar la lectura nos devolverá un String
			// únicamente, por lo que deberemos luego partirlo en varias líneas
			// con el método split
			String linea = reader.readLine();
			lineas = linea.split("<br/>");

			reader.close();
		} else {
			Log.e("BionicBasket", conexion.getResponseMessage());
		}
		conexion.disconnect();

		return lineas;
	}

	// Clase utilizada para el AsyncTask, la cual realizará la búsqueda mediante
	// la función anterior y almacenará los resultados en el almacén de datos
	// previamente definido
	class DescargarDatos extends AsyncTask<Void, Void, String[]> {
		private ProgressDialog progreso;

		@Override
		protected void onPreExecute() {
			progreso = new ProgressDialog(MainActivity.this);
			progreso.setProgressStyle(ProgressDialog.STYLE_SPINNER);
			progreso.setMessage("Descargando datos...");
			progreso.setCancelable(false);
			progreso.show();
		}

		@Override
		protected String[] doInBackground(Void... arg0) {
			try {
				return busquedaDatos();
			} catch (Exception e) {
				cancel(true);
				Log.e("BionicBasket", e.getMessage(), e);
				return null;
			}
		}

		@Override
		protected void onPostExecute(String[] resultado) {
			progreso.dismiss();
			// Guardado de los datos en la base de datos
			almacen.guardarEstadisticas(resultado);
			almacen.guardarCalendario(resultado);
			almacen.guardarClasificacion(resultado);

			// Guardado de los datos en la clase correspondiente
			almacen.cargarEstadisticas();
			almacen.cargarCalendario();
			almacen.cargarClasificacion();
		}

		@Override
		protected void onCancelled() {
			progreso.dismiss();
		}
	}
}
